0.9.9 API documentation: vector_int3_precision.hpp File Reference

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

Typedefs
vector_int3_precision.hpp File Reference

Core features More...

Go to the source code of this file.

## Typedefs
typedef vec< 3, int, highp > | highp_ivec3
| 3 components vector of high qualifier signed integer numbers. More...
typedef vec< 3, int, lowp > | lowp_ivec3
| 3 components vector of low qualifier signed integer numbers. More...
typedef vec< 3, int, mediump > | mediump_ivec3
| 3 components vector of medium qualifier signed integer numbers. More...

## Detailed Description

Core features

Definition in file vector_int3_precision.hpp.